# Generated by roxygen2: do not edit by hand

export(dockeriseStudy)
export(initStudy)
export(linkGitHub)
export(pushDockerImage)
export(reviewStudy)
export(runRStudio)
export(runStudy)
export(stopStudy)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,read_json)
importFrom(rlang,.data)
importFrom(rlang,.env)
importFrom(utils,browseURL)
importFrom(utils,head)
importFrom(utils,install.packages)
