# {{REPO_NAME}}

This is an OMOP CDM study repository.

Created: {{DATE}}

## Repository Structure

- `studyCode/` - Analysis code and cohort definitions
- `studyShiny/` - Interactive results viewer
- `diagnosticsCode/` - Cohort diagnostics code
- `diagnosticsShiny/` - Diagnostics results viewer
- `results/` - Study results (excluded from version control)

## About

This repository was created with [OmopStudyBuilder](https://github.com/oxford-pharmacoepi/OmopStudyBuilder), an R package for building reproducible OMOP CDM network studies.
