# Diagnostics Shiny App

This folder is a scaffold for a Shiny app used to explore diagnostic outputs.

## Instructions

For detailed instructions on how to run the diagnostics shiny app, please see the [INSTRUCTIONS.md](../INSTRUCTIONS.md) file in the root directory of this repository.
