# Diagnostics Code

This folder contains the diagnostic code needed before running the main study analysis.

## Instructions

For detailed instructions on how to run the diagnostics code, please see the [INSTRUCTIONS.md](../INSTRUCTIONS.md) file in the root directory of this repository.




