
<!-- README.md is generated from README.Rmd. Please edit that file -->

# OmopStudyBuilder <a href="https://github.com/oxford-pharmacoepi/OmopStudyBuilder"><img src="man/figures/image.jfif" align="right" height="138" alt="OmopStudyBuilder website" /></a>

<!-- badges: start -->

[![R-CMD-check](https://github.com/oxford-pharmacoepi/OmopStudyBuilder/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/oxford-pharmacoepi/OmopStudyBuilder/actions/workflows/R-CMD-check.yaml)
[![CRAN
status](https://www.r-pkg.org/badges/version/OmopStudyBuilder)](https://CRAN.R-project.org/package=OmopStudyBuilder)
[![Lifecycle:
experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg)](https://lifecycle.r-lib.org/articles/stages.html#experimental)
[![Codecov test
coverage](https://codecov.io/gh/oxford-pharmacoepi/OmopStudyBuilder/branch/main/graph/badge.svg)](https://app.codecov.io/gh/oxford-pharmacoepi/OmopStudyBuilder?branch=main)
<!-- badges: end -->

The goal of OmopStudyBuilder is to help you prepare study for network
studies using the OMOP CDM. The package takes care of setting up a R
project for your study with the default structure and generic code that
would be used for most network studies. This then leaves you to add the
code that is unique to your study.

The package is highly opinionated and designed to align with the OxInfer
study code checklist
<https://oxford-pharmacoepi.github.io/Oxinfer/onboarding/code_review.html>
