#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom jsonlite fromJSON read_json
#' @importFrom rlang .data
#' @importFrom rlang .env
#' @importFrom utils head install.packages
## usethis namespace: end
NULL
