# {{STUDY_TITLE}}
<img src="https://img.shields.io/badge/Study%20Status-{{STUDY_STATUS}}-blue.svg" alt="Study Status: {{STUDY_STATUS}}">

- **Study title**: {{STUDY_TITLE}}
- **Study start date**: {{STUDY_START}}
- **Study leads**: {{STUDY_LEADS}}
- **Study end date**: {{STUDY_END}}
- **Publications**: {{PUBLICATIONS}}

## Study Description

{{STUDY_DESCRIPTION}}

---

## Repository Organization

This repository is organised as follows:

{{FOLDER_STRUCTURE}}

---

For detailed instructions on how to run the study, please see the [INSTRUCTIONS.md](./INSTRUCTIONS.md) file.

---

*This study template was generated using [OmopStudyBuilder](https://oxford-pharmacoepi.github.io/OmopStudyBuilder/).*
