% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reviewStudy.R
\name{reviewStudy}
\alias{reviewStudy}
\title{Review a study directory}
\usage{
reviewStudy(dir, code = TRUE, dependencies = TRUE, type = "analysis")
}
\arguments{
\item{dir}{Path to the study directory.}

\item{code}{If `TRUE`, summarises R, JSON, CSV, and Excel files found in
the directory.}

\item{dependencies}{If `TRUE`, summarises the renv.lock dependencies.}

\item{type}{Whether the R project is for analysis code or study reporting.
Only used when `dependencies = TRUE`.}
}
\value{
Invisibly returns `NULL`. Called for its side effects of printing
  summaries to the console.
}
\description{
Summarises the code and/or renv dependencies in a study directory.
}
