% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/linkGitHub.R
\name{checkGitHubAuth}
\alias{checkGitHubAuth}
\title{Check GitHub authentication}
\usage{
checkGitHubAuth()
}
\description{
Check GitHub authentication
}
\keyword{internal}
