% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dockerWrapper.R
\name{runRStudio}
\alias{runRStudio}
\title{Run RStudio Server for interactive study execution}
\usage{
runRStudio(
  image_name = NULL,
  results_path = "./results",
  env_file = NULL,
  port = 8787,
  password = NULL
)
}
\arguments{
\item{image_name}{Name of Docker image to run (default: auto-detected from directory)}

\item{results_path}{Path to save results (default: "./results")}

\item{env_file}{Optional path to a .env file (passed to Docker via --env-file).
If NULL and a `.env` file exists in the current working directory, it will be
used automatically.}

\item{port}{Port for RStudio Server (default: 8787, auto-finds next available if busy)}

\item{password}{RStudio password (default: auto-generated and displayed)}
}
\value{
Container ID (invisibly)
}
\description{
Note: The Docker image must include RStudio Server (i.e., be built with
`dockeriseStudy(useRStudio = TRUE)` which uses a `rocker/rstudio` base image).
}
