% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/linkGitHub.R
\name{initializeGitRepo}
\alias{initializeGitRepo}
\title{Initialize local git repository}
\usage{
initializeGitRepo(directory)
}
\description{
Initialize local git repository
}
\keyword{internal}
